Method: Sunspot::Query::Restriction.names

Defined in:
lib/sunspot/query/restriction.rb

.namesObject

Return the names of all of the restriction classes that should be made available to the DSL.

Returns

Array

Collection of restriction class names



13
14
15
# File 'lib/sunspot/query/restriction.rb', line 13

def names
  constants - abstract_constants
end